Authors
=======

Developer:
    - Andrés Marín <Andres.LAVERDE-MARIN@ext.ec.europa.eu>
    - Dimitris Komnos <Dimitrios.KOMNOS@ext.ec.europa.eu>
    - Vincenzo Arcidiacono <Vincenzo.ARCIDIACONO@ext.ec.europa.eu>
    - Ashenafi Makie <ashenafimenza@gmail.com>
Documentation:
    - Andrés Marín <Andres.LAVERDE-MARIN@ext.ec.europa.eu>
Model:
    - Michail Makridis <mmakridis@ethz.ch>
    - Georgios Fontaras <georgios.fontaras@ec.europa.eu>
    - Biagio Ciuffo <Biagio.CIUFFO@ec.europa.eu>
    - Konstantinos Mattas <konstantinos.mattas@ec.europa.eu>
    - Yinglong He <yhe.phd@gmail.com>
    - Dimitris Komnos <Dimitrios.KOMNOS@ext.ec.europa.eu>
    - Andrés Marín <Andres.LAVERDE-MARIN@ext.ec.europa.eu>
Supervision:
    - Georgios Fontaras <georgios.fontaras@ec.europa.eu>
    - Biagio Ciuffo <Biagio.CIUFFO@ec.europa.eu>
    - Michail Makridis <mmakridis@ethz.ch>
IT administration:
    - Athina Mitsiara <Athina.MITSIARA@ext.ec.europa.eu>
Tester:
    - Dimitris Komnos <Dimitrios.KOMNOS@ext.ec.europa.eu>
    - Jaime Suarez <Jaime.SUAREZ-CORUJO@ec.europa.eu>
